pub trait AtContext<const SIZE: usize> {
// Provided methods
fn exec(&self) -> AtResult<'_, SIZE> { ... }
fn query(&mut self) -> AtResult<'_, SIZE> { ... }
fn test(&mut self) -> AtResult<'_, SIZE> { ... }
fn set(&mut self, _args: Args<'_>) -> AtResult<'_, SIZE> { ... }
}Expand description
Trait that defines the context for AT command execution. Implementations of this trait handle the actual logic for each AT command form.
The const generic SIZE defines the size (in bytes) of the response buffer
returned by command handlers.
Provided Methods
Sourcefn exec(&self) -> AtResult<'_, SIZE>
fn exec(&self) -> AtResult<'_, SIZE>
Execute command (AT+CMD) This is called when a command is invoked without any suffix.
Sourcefn query(&mut self) -> AtResult<'_, SIZE>
fn query(&mut self) -> AtResult<'_, SIZE>
Query command (AT+CMD?) This is called to retrieve the current value/state of a command.